@@ -2,13 +2,13 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from kornet.strategy.machines.models import OS, RAM, Processor
+from kornet.strategy.machines.models import OS, RAM, MachineFacts, Processor
 
 if TYPE_CHECKING:
     from kornet.strategy.orders.models import OrderOutcome
 
 
-def os_parser(outcome: OrderOutcome) -> OS:
+def os_parser(outcome: OrderOutcome) -> MachineFacts:
     known_facts = {"name": "", "version": ""}
 
     for line in outcome.outputs:
@@ -17,10 +17,10 @@ def os_parser(outcome: OrderOutcome) -> OS:
         elif line.startswith("VERSION="):
             known_facts["version"] = line.split("=")[1].replace('"', "")
 
-    return OS(**known_facts)
+    return MachineFacts(os=OS(**known_facts))
 
 
-def cpu_parser(outcome: OrderOutcome) -> Processor:
+def cpu_parser(outcome: OrderOutcome) -> MachineFacts:
     known_facts = {"model": "", "cores": 0, "arch": ""}
 
     for line in outcome.outputs:
@@ -30,10 +30,10 @@ def cpu_parser(outcome: OrderOutcome) -> Processor:
     known_facts["cores"] = int(outcome.outputs[-2].strip())
     known_facts["arch"] = outcome.outputs[-1].strip()
 
-    return Processor(**known_facts)
+    return MachineFacts(cpu=Processor(**known_facts))
 
 
-def ram_parser(outcome: OrderOutcome) -> RAM:
+def ram_parser(outcome: OrderOutcome) -> MachineFacts:
     known_facts = {"total": 0, "available": 0}
     for line in outcome.outputs:
         if line.startswith("Mem"):
@@ -41,4 +41,8 @@ def ram_parser(outcome: OrderOutcome) -> RAM:
             known_facts["available"] = int(line.split()[3])
             break
 
-    return RAM(**known_facts)
+    return MachineFacts(ram=RAM(**known_facts))
+
+
+def hostname_parser(outcome: OrderOutcome) -> MachineFacts:
+    return MachineFacts(hostname=outcome.outputs[0].strip())
